%define anolis_release 1

# The testsuite is unsuitable for running on buildsystems
%global tests_enabled 0

Summary: System and process monitoring utilities
Name: procps-ng
Version: 4.0.4
Release: %{anolis_release}%{?dist}
License: GPL-2.0-or-later AND LGPL-2.0-or-later AND LGPL-2.1-or-later
URL: https://sourceforge.net/projects/procps-ng/

Source0: https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz

BuildRequires: make
BuildRequires: ncurses-devel
BuildRequires: libtool
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gcc
BuildRequires: gettext-devel
BuildRequires: systemd-devel
BuildRequires: git
BuildRequires: po4a

%if %{tests_enabled}
BuildRequires: dejagnu
%endif

Provides: procps = %{version}-%{release}
Obsoletes: procps < 4.0.1-1

# usrmove hack - will be removed once initscripts are fixed
Provides: /sbin/sysctl
Provides: /bin/ps


%description
The procps package contains a set of system utilities that provide
system information. Procps includes ps, free, skill, pkill, pgrep,
snice, tload, top, uptime, vmstat, pidof, pmap, slabtop, w, watch,
pwdx and pidwait.
The ps command displays a snapshot of running processes. The top command
provides a repetitive update of the statuses of running processes.
The free command displays the amounts of free and used memory on your
system. The skill command sends a terminate command (or another
specified signal) to a specified set of processes. The snice
command is used to change the scheduling priority of specified
processes. The tload command prints a graph of the current system
load average to a specified tty. The uptime command displays the
current time, how long the system has been running, how many users
are logged on, and system load averages for the past one, five,
and fifteen minutes. The w command displays a list of the users
who are currently logged on and what they are running. The watch
program watches a running program. The vmstat command displays
virtual memory statistics about processes, memory, paging, block
I/O, traps, and CPU activity. The pwdx command reports the current
working directory of a process or processes. The pidwait command
waits for processes of specified names.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:  System and process monitoring utilities
Requires: %{name} = %{EVR}
Provides: procps-devel = %{EVR}
Obsoletes: procps-devel < 3.3.17-8

%description devel
System and process monitoring utilities development headers

%package i18n
Summary:  Internationalization pack for procps-ng
Requires: %{name} = %{EVR}
BuildArch: noarch

# fortunately the same release number for f21 and f22
Conflicts: man-pages-de < 1.7-3
Conflicts: man-pages-fr < 3.66-3
Conflicts: man-pages-pl < 0.7-5

%description i18n
Internationalization pack for procps-ng

%prep
%autosetup -n procps-ng-%{version} -p1
#-S git

%build
# The following stuff is needed for git archives only
#echo "%{version}" > .tarball-version
#./autogen.sh

autoreconf --verbose --force --install

%configure \
           --exec-prefix=/ \
           --disable-static \
           --disable-w-from \
           --disable-kill \
           --enable-watch8bit \
           --enable-skill \
           --enable-sigwinch \
           --enable-libselinux \
           --with-systemd \
           --disable-modern-top\
           --enable-pidwait

make CFLAGS="%{optflags}"


%if %{tests_enabled}
%check
make check
%endif


%install
%make_install

# these are created by make, yet empty. This causes rpmbuild errors.
rm -rf %{buildroot}%{_mandir}/pl/man5
rm -rf %{buildroot}%{_mandir}/{fr,de,pt_BR}/man3

%find_lang %{name} --all-name --with-man

ln -s %{_bindir}/pidof %{buildroot}%{_sbindir}/pidof

%generate_compatibility_deps
%ldconfig_scriptlets

%files
%license COPYING COPYING.LIB
%doc bugs.md FAQ
%dir %{abidir}
%{_libdir}/libproc2.so.*
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*
%{abidir}/*-option.list

%exclude %{_pkgdocdir}/libproc.supp

%files doc
%doc AUTHORS NEWS README.md

%files devel
%license COPYING COPYING.LIB
%{_libdir}/libproc2.so
%{abidir}/libproc2.dump
%{_libdir}/pkgconfig/libproc2.pc
%{_includedir}/libproc2
%{_mandir}/man3/*

%files i18n -f %{name}.lang

%changelog
* Wed Feb 21 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.0.4-1
- update to 4.0.4

* Fri Aug 18 2023 Funda Wang <fundawang@yeah.net> - 3.3.17-5
- fix CVE-2023-4016

* Wed Apr 12 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 3.3.17-4
- Refactor the specfile

* Wed Jan 04 2023 happy_orange <songnannan@linux.alibaba.com> - 3.3.17-3
- add some patches and abi api files

* Wed Sep 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.3.17-2
- add doc package

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 3.3.17-1
- Init version from upstream v3.3.17
